@@ -53,9 +53,9 @@ load_cache <- function(file, path = NULL) {
         invokeRestart("muffleWarning")
       },
       error = function(e) {
-        warning(
-          "Could not load cache file '", file, "':\n",
-          conditionMessage(e)
+        cli_warn(
+          "Could not load cache file {.file {file}}:",
+          parent = e
         )
       }
     )
@@ -127,9 +127,8 @@ retrieve_lint <- function(cache, expr, linter, lines) {
     )
     if (is.na(new_line_number)) {
       return(NULL)
-    } else {
-      lints[[i]]$line_number <- new_line_number
     }
+    lints[[i]]$line_number <- new_line_number
   }
   cache_lint(cache, expr, linter, lints)
   lints
