@@ -28,3 +28,19 @@ test_that("empty_assignment_linter blocks disallowed usages", {
   # LHS of assignment doesn't matter
   expect_lint("env$obj <- {}", lint_msg, linter)
 })
+
+test_that("lints vectorize", {
+  lint_msg <- rex::rex("Assign NULL explicitly or, whenever possible, allocate the empty object")
+
+  expect_lint(
+    trim_some("{
+      x <- {}
+      y = {}
+    }"),
+    list(
+      list(lint_msg, line_number = 2L),
+      list(lint_msg, line_number = 3L)
+    ),
+    empty_assignment_linter()
+  )
+})
