@@ -1,6 +1,6 @@
 test_that("unneeded_concatenation_linter generates deprecation warning", {
   expect_warning(
-    linter <- unneeded_concatenation_linter(),
+    unneeded_concatenation_linter(),
     rex::rex("Linter unneeded_concatenation_linter was deprecated")
   )
 })
